==> jwinner-base-0.0.6-sources.jar: itez/plat/site/model/base/BaseInfo.java <==
package itez.plat.site.model.base;

import itez.core.wrapper.dbo.model.EModel;
import com.jfinal.plugin.activerecord.IBean;

/**
 * 由JWinner Model Generator自动生成，请勿修改本文件。
 */
@SuppressWarnings({"serial", "unchecked"})
public abstract class BaseInfo<M extends BaseInfo<M>> extends EModel<M> implements IBean {

	public M setId(java.lang.String id) {
		set("id", id);
		return (M)this;
	}
	
	public java.lang.String getId() {
		return getStr("id");
	}

	public M setDomain(java.lang.String domain) {
		set("domain", domain);
		return (M)this;
	}
	
	public java.lang.String getDomain() {
		return getStr("domain");
	}

	public M setIndex(java.lang.String index) {
		set("index", index);
		return (M)this;
	}
	
	public java.lang.String getIndex() {
		return getStr("index");
	}

	public M setCaption(java.lang.String caption) {
		set("caption", caption);
		return (M)this;
	}
	
	public java.lang.String getCaption() {
		return getStr("caption");
	}

	public M setSubCaption(java.lang.String subCaption) {
		set("subCaption", subCaption);
		return (M)this;
	}
	
	public java.lang.String getSubCaption() {
		return getStr("subCaption");
	}

	public M setWelcome(java.lang.String welcome) {
		set("welcome", welcome);
		return (M)this;
	}
	
	public java.lang.String getWelcome() {
		return getStr("welcome");
	}

	public M setCdate(java.util.Date cdate) {
		set("cdate", cdate);
		return (M)this;
	}
	
	public java.util.Date getCdate() {
		return get("cdate");
	}

	public M setUdate(java.util.Date udate) {
		set("udate", udate);
		return (M)this;
	}
	
	public java.util.Date getUdate() {
		return get("udate");
	}

	public M setUsed(java.lang.Integer used) {
		set("used", used);
		return (M)this;
	}
	
	public java.lang.Integer getUsed() {
		return getInt("used");
	}

}

==> jwinner-base-0.1.7-sources.jar: itez/plat/site/model/base/BaseInfo.java <==
package itez.plat.site.model.base;

import itez.core.wrapper.dbo.model.EModel;
import com.jfinal.plugin.activerecord.IBean;

/**
 * 由JWinner Model Generator自动生成，请勿修改本文件。
 */
@SuppressWarnings({"serial", "unchecked"})
public abstract class BaseInfo<M extends BaseInfo<M>> extends EModel<M> implements IBean {

	public M setId(java.lang.String id) {
		set("id", id);
		return (M)this;
	}
	
	public java.lang.String getId() {
		return getStr("id");
	}

	public M setDomain(java.lang.String domain) {
		set("domain", domain);
		return (M)this;
	}
	
	public java.lang.String getDomain() {
		return getStr("domain");
	}

	public M setSubDomain(java.lang.String subDomain) {
		set("subDomain", subDomain);
		return (M)this;
	}
	
	public java.lang.String getSubDomain() {
		return getStr("subDomain");
	}

	public M setIndex(java.lang.String index) {
		set("index", index);
		return (M)this;
	}
	
	public java.lang.String getIndex() {
		return getStr("index");
	}

	public M setCaption(java.lang.String caption) {
		set("caption", caption);
		return (M)this;
	}
	
	public java.lang.String getCaption() {
		return getStr("caption");
	}

	public M setSubCaption(java.lang.String subCaption) {
		set("subCaption", subCaption);
		return (M)this;
	}
	
	public java.lang.String getSubCaption() {
		return getStr("subCaption");
	}

	public M setWelcome(java.lang.String welcome) {
		set("welcome", welcome);
		return (M)this;
	}
	
	public java.lang.String getWelcome() {
		return getStr("welcome");
	}

	public M setUseCountor(java.lang.Integer useCountor) {
		set("useCountor", useCountor);
		return (M)this;
	}
	
	public java.lang.Integer getUseCountor() {
		return getInt("useCountor");
	}

	public M setCdate(java.util.Date cdate) {
		set("cdate", cdate);
		return (M)this;
	}
	
	public java.util.Date getCdate() {
		return get("cdate");
	}

	public M setUdate(java.util.Date udate) {
		set("udate", udate);
		return (M)this;
	}
	
	public java.util.Date getUdate() {
		return get("udate");
	}

	public M setUsed(java.lang.Integer used) {
		set("used", used);
		return (M)this;
	}
	
	public java.lang.Integer getUsed() {
		return getInt("used");
	}

}
